// Generated by gmmproc 2.66.8 -- DO NOT MODIFY!
#ifndef _GLIBMM_VALUEARRAY_P_H
#define _GLIBMM_VALUEARRAY_P_H
#ifndef GLIBMM_DISABLE_DEPRECATED


#endif // GLIBMM_DISABLE_DEPRECATED


#endif /* _GLIBMM_VALUEARRAY_P_H */

